summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/kernel/tqpainter_x11.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/kernel/tqpainter_x11.cpp')
-rw-r--r--tqtinterface/qt4/src/kernel/tqpainter_x11.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tqtinterface/qt4/src/kernel/tqpainter_x11.cpp b/tqtinterface/qt4/src/kernel/tqpainter_x11.cpp
index ac788d4..05d5c76 100644
--- a/tqtinterface/qt4/src/kernel/tqpainter_x11.cpp
+++ b/tqtinterface/qt4/src/kernel/tqpainter_x11.cpp
@@ -1148,7 +1148,7 @@ void TQPainter::updateBrush()
if ( pat ) {
TQString key;
key.sprintf( "$qt-brush$%d", bs );
- pm = TQPixmapCache::tqfind( key );
+ pm = TQPixmapCache::find( key );
bool del = FALSE;
if ( !pm ) { // not already in pm dict
pm = new TQBitmap( d, d, pat, TRUE );
@@ -3093,7 +3093,7 @@ void TQPainter::drawTiledPixmap( int x, int y, int w, int h,
#if 0
//
// Generate a string that describes a transformed bitmap. This string is used
// to insert and tqfind bitmaps in the global pixmap cache.
//
static TQString gen_text_bitmap_key( const TQWMatrix &m, const TQFont &font,
@@ -3124,7 +3124,7 @@ static TQString gen_text_bitmap_key( const TQWMatrix &m, const TQFont &font,
static TQBitmap *get_text_bitmap( const TQString &key )
{
- return (TQBitmap*)TQPixmapCache::tqfind( key );
+ return (TQBitmap*)TQPixmapCache::find( key );
}
static void ins_text_bitmap( const TQString &key, TQBitmap *bm )
@@ -3093,7 +3093,7 @@ void TQPainter::drawTiledPixmap( int x, int y, int w, int h,
//
// Generate a string that describes a transformed bitmap. This string is used
-// to insert and tqfind bitmaps in the global pixmap cache.
+// to insert and find bitmaps in the global pixmap cache.
//
static TQString gen_text_bitmap_key( const TQWMatrix &m, const TQFont &font,